==> magics++_2.8.0.dfsg.orig.tar.gz: magics++-2.8.0.dfsg/src/visualisers/Coastlines.cc <==
/******************************** LICENSE ********************************

 Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 ******************************** LICENSE ********************************/

/*! \file Coastlines.cc
    \brief Implementation of the Template class Coastlines.
    
    Magics Team - ECMWF 2004
    
    Started: Thu 29-Jan-2004
    
    Changes:
    
*/

#include "Coastlines.h"
#include "Layer.h"

using namespace magics;

Coastlines::Coastlines() 
{
  
}

Coastlines::~Coastlines() {}

/*!
 Class information are given to the output-stream.
*/		
void Coastlines::print(ostream& out)  const
{
	out << "Coastlines[";
	CoastlinesAttributes::print(out);
	out << "]";
}


#include "Transformation.h"

void Coastlines::visit(DrawingVisitor& parent)
{
	 Layer* layer = new Layer("coastlines");
	 parent.push_back(layer);
	 
	 coastlines_->layer(layer);
	(*coastlines_)(parent);
	coastlines_->layer(0);
	 
	grid_->layer(layer);
	(*grid_)(parent);
	 grid_->layer(0);

	(*label_).prepare(*grid_);
	label_->layer(layer);
	(*label_)(parent);
	label_->layer(0);
}

void Coastlines::visit(LeftAxisVisitor& parent)
{
	(*label_).prepare(*grid_); 
	(*label_)(parent);
}

void Coastlines::visit(RightAxisVisitor& parent)
{
	(*label_).prepare(*grid_); 
	(*label_)(parent);
}

void Coastlines::visit(TopAxisVisitor& parent)
{	
	(*label_).prepare(*grid_); 
	(*label_)(parent);
}

void Coastlines::visit(BottomAxisVisitor& parent)
{
	(*label_).prepare(*grid_); 
	(*label_)(parent);
}


void Coastlines::visit(PreviewVisitor& preview)
{	
	(*coastlines_)(preview);
}

==> magics++_2.10.0.dfsg.orig.tar.gz: magics++-2.10.0.dfsg/src/visualisers/Coastlines.cc <==
/******************************** LICENSE ********************************

 Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 ******************************** LICENSE ********************************/

/*! \file Coastlines.cc
    \brief Implementation of the Template class Coastlines.
    
    Magics Team - ECMWF 2004
    
    Started: Thu 29-Jan-2004
    
    Changes:
    
*/

#include "Coastlines.h"
#include "Layer.h"

using namespace magics;

Coastlines::Coastlines() 
{
  
}

Coastlines::~Coastlines() {}

/*!
 Class information are given to the output-stream.
*/		
void Coastlines::print(ostream& out)  const
{
	out << "Coastlines[";
	CoastlinesAttributes::print(out);
	out << "]";
}


#include "Transformation.h"

void Coastlines::visit(DrawingVisitor& parent)
{
	 Layer* layer =  LayerManager::layer("coastlines");
	 
	
	 parent.push_back(layer);
	 
	 coastlines_->layer(layer);
	(*coastlines_)(parent);
	coastlines_->layer(0);
	 
	grid_->layer(layer);
	(*grid_)(parent);
	 grid_->layer(0);

	(*label_).prepare(*grid_);
	label_->layer(layer);
	(*label_)(parent);
	label_->layer(0);
}

void Coastlines::visit(LeftAxisVisitor& parent)
{
	(*label_).prepare(*grid_); 
	(*label_)(parent);
}

void Coastlines::visit(RightAxisVisitor& parent)
{
	(*label_).prepare(*grid_); 
	(*label_)(parent);
}

void Coastlines::visit(TopAxisVisitor& parent)
{	
	(*label_).prepare(*grid_); 
	(*label_)(parent);
}

void Coastlines::visit(BottomAxisVisitor& parent)
{
	(*label_).prepare(*grid_); 
	(*label_)(parent);
}


void Coastlines::visit(PreviewVisitor& preview)
{	
	(*coastlines_)(preview);
}
